/*
 * file StpMessageException.java
 *
 * (C) Copyright IBM Corporation 2008, 2014.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 */

package com.ibm.rational.wvcm.stp;

import javax.wvcm.Resource;
import javax.wvcm.ResourceList;
import javax.wvcm.WvcmException.ReasonCode;

import com.ibm.rational.wvcm.stp.StpPartialResultsException.PartialResultsData;
import com.ibm.rational.wvcm.stp.StpPropertyException.PropertyData;

/**
 * An StpException used to pass an error message string generated by the domain
 * application through the CM API without further adornment.
 */
public abstract class StpErrorMessageException extends StpPropertyException
{
    /**
     * @return The message string exactly as generated by the domain application
     *         without the additional context information provided by the server
     *         or client libraries when forming the string returned by the
     *         toString, getMessage or getLocalizedMessage methods of this
     *         Throwable object.
     */
    public String errorMessage()
    {
        return ((ErrorMessageData)data()).errorMessage();
    }

    /*
     * @param resource
     * @param reasonCode
     * @param nestedExceptions
     */
    protected StpErrorMessageException(Resource resource,
                               ReasonCode reasonCode,
                               Throwable... nestedExceptions)
    {
        super(resource, reasonCode, nestedExceptions);
    }

    /** 
     * The interface for the data implementation object for this type of 
     * exception
     */
    public interface ErrorMessageData extends PropertyData {
        public String errorMessage();
    }
}
